{ 3D_POST_PROCESSING.PDE

  This example demonstrates the use of the TRANSFERMESH facility to import
  both data and mesh structure from 3D_MESH_EXPORT.PDE and perform
  post-processing without gridding or solving any equations.

  This is easily accomplished in a step-wise process:
  1) make a copy of the script that generated the exported data
  2) remove the VARIABLES and EQUATIONS sections
  3) remove any boundary conditions stated in the BOUNDARIES section
  4) add the TRANSFERMESH statement in the DEFINITIONS section
  5) add any new plots that you desire

  Note that the domain structure must exactly match that of the exporting problem.

  3D_MESH_EXPORT.PDE must be run before running this problem.

}

title 'Using TRANSFERMESH for post-processing'

coordinates cartesian3

definitions
    k = 1
    an = pi/4          { this is the angular size of the repeated segment }
    crot = cos(an)     { the sine and cosine needed in the transformation }
    srot = sin(an)
    H = 0
    xc = 1.5
    yc = 0.2
    rc = 0.1
    transfermesh("3d_mesh_export_output/mesh3u.xfr",U)

extrusion z=0,0.4,0.6,1

boundaries
    Region 1

       start(1,0) line to (2,0)
       arc(center=0,0) to (2*crot,2*srot)
       line to (crot,srot)
       arc(center= 0,0)  to close

    Limited Region 2
        layer 2 H=1
        start(xc-rc,0) line to (xc+rc,0) to (xc+rc,rc) to (xc-rc,rc) to close

    Limited Region 3
        layer 2 H=-1
        start((xc-rc)*crot,(xc-rc)*srot)
        line to ((xc+rc)*crot,(xc+rc)*srot)
             to ((xc+rc)*crot+rc*srot,(xc+rc)*srot-rc*crot)
             to ((xc-rc)*crot+rc*srot,(xc-rc)*srot-rc*crot) to close

plots
     grid(x,y,z)
     grid(x,y) on z=0.5
     contour(u) on z=0.5
     contour(u) on z=0.5 zoom(1.3,0,0.4,0.4)
     contour(u) on z=0.5 zoom(1.4,0,0.2,0.2) paint

end "DRJ6LrAMK/1xWc5DtjYFelrPBXiYD+vgdp6rQixwwrQPbhg6A8qraoPUDBPW1r1INQrHAsy8GJizJKUM8iwHY3+T4oUWwH6p5LmY9AGyqP6oL37Sc+D9fiAhAWbKkIGq6bBYO17JLWwnclBS+O/rh52fA74YTs90R24SsbFOO9W"
