{ 3D_BUBBLE_RECONNECT.PDE

  This problem illustrates moving meshes and mesh reconnection in 3D.
  A spherical bubble moves through a column.
  A mesh velocity variable is used to compute the mesh coordinates.
}
TITLE '3D Bubble reconnect - velocity specification'

SELECT
 overshoot = 1e-5
 reconnect(on)
 order=2

COORDINATES
  cartesian3

VARIABLES
  Phi(0.001)    { the temperature }
  Zm = MOVE(z)  { surrogate Z variable}
  Wm(0.01)    { mesh z-velocity }

DEFINITIONS
  K = 1    { default conductivity }
  Vz =  0.1
  length=5

  zc = 1  ! bubble center
  R0 = 0.5    { bubble radius }
  zsphere = SPHERE ((0,0,0),R0)
  z1, z2
 km =100

INITIAL VALUES
  Phi = 0
  Wm=0

INITIAL EQUATIONS
  Phi:  Div(-k*grad(phi)) = 0
  Wm:  div(km*grad(Wm)) = 0

EULERIAN EQUATIONS
  Phi:  Div(k*grad(phi)) = dt(phi)
  Zm:  dt(Zm) = Wm
  Wm:  div(km*grad(Wm)) = 0

EXTRUSION
 SURFACE 'Bottom'          z = 0
  SURFACE 'Sphere Bottom'   z=zc-zsphere
     layer "zbubble"
  SURFACE 'Sphere Top'      z=zc+zsphere
  SURFACE 'Top'             z=length

BOUNDARIES

SURFACE 1
    VALUE(Phi)=0  VELOCITY(Zm)=0  VALUE(Wm)=0
SURFACE 2
    VALUE(Wm) = Vz
    VELOCITY(Zm) = Vz
SURFACE 3
    VALUE(Wm) = Vz
    VELOCITY(Zm) = Vz

 SURFACE 4
    VALUE(Phi)=0  VELOCITY(Zm)=0 VALUE(Wm)=0

REGION 1 'box'
  z1=0   z2=0

  START(1,0)
    VALUE(Phi)=0
    natural(Wm)=0
  LINE TO  (1,1) TO (-1,1) TO(-1,0)
     NATURAL(Phi)=0
     NATURAL(Wm)=0
     NOBC(Zm)
  LINE TO CLOSE

LIMITED
REGION 2  'bubble'  { the embedded bubble }
  z1 = zc-zsphere
  z2 = zc+zsphere
  layer "zbubble"
     k = 0.001
     mesh_spacing = 0.25
  SURFACE 'Sphere Bottom'
    VELOCITY(Zm) = Wm
    VALUE(Wm) = Vz
    value(phi)=1
  SURFACE  'Sphere Top'
     VELOCITY(Zm) = Wm
     VALUE(Wm) = Vz
    value(phi)=1

start(R0,0) arc(center=0,0) angle=180
natural(Wm)=0 line to close

TIME 0 TO 30 by 0.1

PLOTS
for t=0
    GRID(x,y,z) ON 'bubble' ON LAYER "zbubble"
for cycle=1
    grid(X,Z) on y=0  paintregions
    grid(X,Y) on surface 'Sphere Bottom'
    grid(Y,Z) on x=0.33
    CONTOUR(Wm)  notags nominmax ON y=0 as "Mesh Velocity"
    CONTOUR(dt(Wm))  notags nominmax ON y=0 as "Mesh Acceleration"
    CONTOUR(phi)  notags nominmax ON y=0
    CONTOUR(dt(phi)) notags nominmax ON y=0
    glcontour(Wm) on region 1 on layer 1

END "F4x7uX2/Vc35wWMWeB93Pcrplg4vcEOcXBy+ewtpMSAto8sM/vBShk7bWBaZ29Y7Xu93aG4p1eIQR5Zh2xXp1+HIs5NYwiU4FbbgZN1H/fKkUCh3jqVJERiudOw9IBKUi4r4BJ7w+w2wOjClOTmdWo1myCgqZYdUNxagGp69C7f"
